import dayjs from "dayjs";
import { message } from "@/utils/message";
import {
  QyUserQuery,
  getQyUserListApi
} from "@/api/qy/qyUser";
import { ElMessageBox } from "element-plus";
import { type PaginationProps } from "@pureadmin/table";
import { reactive, ref, computed, onMounted, toRaw, h } from "vue";
import { CommonUtils } from "@/utils/common";
import { addDialog } from "@/components/ReDialog";
import userDetail from "./UserDetail.vue";
import { handleTree, setDisabledForTreeOptions } from "@/utils/tree";
import { getQyDeptListApi } from "@/api/system/dept";
import { getPostListApi } from "@/api/system/post";
import { getRoleListApi } from "@/api/system/role";
import { useWxStore } from "@/store/modules/wx";

export function useHook() {
  const wxStore = useWxStore();

  const searchFormParams = reactive<QyUserQuery>({
    /** 姓名（导出列：姓名） */
    name: undefined,
    /** 手机号（导出列：联系方式） */
    mobile: undefined,
    corpid: wxStore.corpid,
    mainDepartment: undefined,
  });

  const formRef = ref();
  const timeRange = ref<[string, string]>();

  const dataList = ref([]);
  const pageLoading = ref(true);
  const switchLoadMap = ref({});
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 8,
    currentPage: 1,
    background: true
  });

  const deptTreeList = ref([]);
  const postOptions = ref([]);
  const roleOptions = ref([]);
  const buttonClass = computed(() => {
    return [
      "!h-[20px]",
      "reset-margin",
      "!text-gray-500",
      "dark:!text-white",
      "dark:hover:!text-primary"
    ];
  });


  async function onSearch() {
    // 点击搜索的时候 需要重置分页
    pagination.currentPage = 1;
    getList();
  }

  async function getList() {
    CommonUtils.fillPaginationParams(searchFormParams, pagination);
    CommonUtils.fillTimeRangeParams(searchFormParams, timeRange.value);

    pageLoading.value = true;
    const { data } = await getQyUserListApi(toRaw(searchFormParams)).finally(
      () => {
        pageLoading.value = false;
      }
    );

    dataList.value = data.rows;
    pagination.total = data.total;
  }

  const resetForm = formEl => {
    if (!formEl) return;
    formEl.resetFields();
    onSearch();
  };

  onMounted(async () => {
    onSearch();
    const deptResponse = await getQyDeptListApi(wxStore.corpid);
    deptTreeList.value = await setDisabledForTreeOptions(
      handleTree(deptResponse.data),
      "status"
    );

    const postResponse = await getPostListApi({});
    postOptions.value = postResponse.data.rows;

    const roleResponse = await getRoleListApi({});
    roleOptions.value = roleResponse.data.rows;
  });

  const handleViewDetail = (row: any) => {
  };

  return {
    searchFormParams,
    pageLoading,
    dataList,
    pagination,
    buttonClass,
    onSearch,
    resetForm,
    getList,
    handleViewDetail
  };
}
